angular.module('app.settings').service('FilterByCorrelationService', function($q, BackendService, AppService, L, DatabankService, SQEvents) {

    function loadDatabanks() {
        DatabankService.loadVisibleDatabanks(instance.config.availableDatabanks);
    }

    this.saveSettings = function() {
        var xmlDoc = AppService.xmlDoc;
        var filteringObj = AppService.getCurrentTaskTabSettings("FilterByCorrelation");
        if(!filteringObj) return;

        //databanks
        var databanksObj = AppService.getCurrentTaskTabSettings("Databanks");
        var databankObjs = getChildElements(databanksObj, 'Databank');

        for(var i=0; i<databankObjs.length; i++) {
            var databankObj = databankObjs[i];

            var databankName = getAttrValue(databankObj, "name", "Results");

            if(databankName=="Source") { databankObj.setAttribute("value", instance.config.databankSource); }
            if(databankName=="Target") { databankObj.setAttribute("value", instance.config.databankTarget); }
			if(databankName=="Existing") { databankObj.setAttribute("value", instance.config.databankExisting); }
        }

        //correlation
        addNode('CorrMax', instance.config.correlation.max, filteringObj, xmlDoc);
        addNode('CorrType', instance.config.correlation.type, filteringObj, xmlDoc);
        addNode('CorrPeriod', instance.config.correlation.period, filteringObj, xmlDoc);
        addNode('CorrAllowNegative', instance.config.correlation.allowNegative, filteringObj, xmlDoc);
        addNode('CorrAddEmptyPeriods', instance.config.correlation.addEmptyPeriods, filteringObj, xmlDoc);
    }
    
    this.loadSettings = function() {
        var filteringObj = AppService.getCurrentTaskTabSettings("FilterByCorrelation");
        if(!filteringObj) return;

        //databanks
        var databanksObj = AppService.getCurrentTaskTabSettings("Databanks");
        var databankObjs = getChildElements(databanksObj, 'Databank');

        for(var i=0; i<databankObjs.length; i++) {
            var databankObj = databankObjs[i];

            var databankName = getAttrStringValue(databankObj, "name", "NA");
            var databankValue = getAttrStringValue(databankObj, "value", "Results");
            
            if(databankName=="Source") { instance.config.databankSource = databankValue; }
            if(databankName=="Target") { instance.config.databankTarget = databankValue; }
			if(databankName=="Existing") { instance.config.databankExisting = databankValue; }
        }

        //correlation
        instance.config.correlation.max = getNodeFloatValue(filteringObj, 'CorrMax', 0.3);
        instance.config.correlation.type = getNodeValue(filteringObj, 'CorrType', 'ProfitLoss');
        instance.config.correlation.period = getNodeIntValue(filteringObj, 'CorrPeriod', 10);
        instance.config.correlation.allowNegative = getNodeBooleanValue(filteringObj, 'CorrAllowNegative', true);
        instance.config.correlation.addEmptyPeriods = getNodeBooleanValue(filteringObj, 'CorrAddEmptyPeriods', false);
    }
	
    var instance = this;

    this.config = {
        //databanks
        databankSource: "Results",
        databankTarget: "Results",
        databankExisting: "Results",
        availableDatabanks: [],

        //correlation
        correlation: {
            max: 0.3,
            type: 'ProfitLoss',
            period: 10,
            allowNegative: true,
            addEmptyPeriods: false
        },
    }
	
    function onEvent(event, data){
        if(event == SQEvents.get("RELOAD_DATABANKS")){
            loadDatabanks();
        }
    }

    SQEvents.addListener("FilterByCorrelationService", [SQEvents.get('RELOAD_DATABANKS')], onEvent);
});